---
title: <span class="badge object-type-enum"></span> MetricKind
---
# <span class="badge object-type-enum"></span> MetricKind

## Definition

```python
class MetricKind(enum.StrEnum):
    METRIC_KIND_UNSPECIFIED = "METRIC_KIND_UNSPECIFIED"
    GAUGE = "GAUGE"
    DELTA = "DELTA"
    CUMULATIVE = "CUMULATIVE"
```
